@@ -45,7 +45,7 @@
 
 static const QStringList sCategories = { i18n("Contacts") };
 
-Q_DECLARE_METATYPE(KContacts::Addressee*)
+Q_DECLARE_METATYPE(KContacts::Addressee *)
 
 PIMContactsRunner::PIMContactsRunner(QObject *parent, const QVariantList &args)
     : Plasma::AbstractRunner(parent, args)
@@ -54,8 +54,8 @@ PIMContactsRunner::PIMContactsRunner(QObject *parent, const QVariantList &args)
     setObjectName(QStringLiteral("PIMContactsRunner"));
     setSpeed(Plasma::AbstractRunner::SlowSpeed);
     setIgnoredTypes(Plasma::RunnerContext::FileSystem
-                        | Plasma::RunnerContext::Executable
-                        | Plasma::RunnerContext::NetworkLocation);
+                    | Plasma::RunnerContext::Executable
+                    | Plasma::RunnerContext::NetworkLocation);
 
     // reloadConfiguration() called by default init() implementation
 }
@@ -64,7 +64,6 @@ PIMContactsRunner::~PIMContactsRunner()
 {
 }
 
-
 void PIMContactsRunner::reloadConfiguration()
 {
     mQueryAutocompleter = config().readEntry(QStringLiteral("queryAutocompleter"), true);
@@ -93,7 +92,7 @@ void PIMContactsRunner::match(Plasma::RunnerContext &context)
 
     queryContacts(context, queryString);
 
-    qDebug() << this << "MATCH: queryAutocompleter =" << mQueryAutocompleter;
+    qCDebug(AKONADI_KRUNNER_LOG) << this << "MATCH: queryAutocompleter =" << mQueryAutocompleter;
     if (mQueryAutocompleter) {
         queryAutocompleter(context, queryString);
     }
@@ -137,7 +136,7 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context,
         return;
     }
 
-    Q_FOREACH (const Akonadi::Item &item, fetch->items()) {
+    for (const Akonadi::Item &item : fetch->items()) {
 
         KContacts::Addressee contact;
         try {
@@ -163,7 +162,7 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context,
         Plasma::QueryMatch match(this);
         match.setMatchCategory(sCategories[0]);
         match.setRelevance(0.75); // 0.75 is used by most runners, we don't
-                                  // want to shadow them
+        // want to shadow them
         match.setMimeType(KContacts::Addressee::mimeType());
 
         const KContacts::Picture photo = contact.photo();
@@ -186,17 +185,17 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context,
         if (name == queryString) {
             match.setType(Plasma::QueryMatch::ExactMatch);
 
-        // We got perfect match by one of the email addresses
+            // We got perfect match by one of the email addresses
         } else if (emails.contains(queryString)) {
             match.setType(Plasma::QueryMatch::ExactMatch);
             matchedEmail = queryString;
 
-        // We got partial match either by name, or email
+            // We got partial match either by name, or email
         } else {
             match.setType(Plasma::QueryMatch::PossibleMatch);
 
             // See if the match was by one of the email addresses
-            Q_FOREACH (const QString &email, emails) {
+            for (const QString &email : emails) {
                 if (email.startsWith(queryString)) {
                     matchedEmail = email;
                     break;
@@ -211,7 +210,7 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context,
             match.setData(QStringLiteral("mailto:%1<%2>").arg(name, matchedEmail));
             context.addMatch(match);
         } else {
-            Q_FOREACH (const QString &email, emails) {
+            for (const QString &email : emails) {
                 Plasma::QueryMatch alternativeMatch = match;
                 alternativeMatch.setText(i18nc("Name (email)", "%1 (%2)", name, email));
                 alternativeMatch.setData(QStringLiteral("mailto:%1<%2>").arg(name, email));
@@ -223,12 +222,12 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context,
 }
 
 void PIMContactsRunner::queryAutocompleter(Plasma::RunnerContext &context,
-                                           const QString &queryString)
+        const QString &queryString)
 {
     Akonadi::Search::PIM::ContactCompleter completer(queryString);
     const QStringList completerResults = completer.complete();
     qCDebug(AKONADI_KRUNNER_LOG) << "Autocompleter returned"  << completerResults.count() << "results";
-    Q_FOREACH (const QString &result, completerResults) {
+    for (const QString &result : completerResults) {
         Plasma::QueryMatch match(this);
         match.setRelevance(0.7); // slightly lower relevance than real addressbook contacts
         match.setMimeType(KContacts::Addressee::mimeType());
@@ -269,7 +268,6 @@ void PIMContactsRunner::run(const Plasma::RunnerContext &context,
     }
 }
 
-
 K_EXPORT_PLASMA_RUNNER(pimcontactsrunner, PIMContactsRunner)
 
 #include "pimcontactsrunner.moc"
